#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.init = void 0;
require("reflect-metadata");
const inversify_1 = require("inversify");
const cli_1 = require("./controllers/cli");
const types_1 = require("./types");
const template_engine_1 = require("./services/template-engine");
const file_output_stream_1 = require("./services/file-output-stream");
const tag_comments_parser_1 = require("./services/tag-comments-parser");
const msdn_comments_parser_1 = require("./services/msdn-comments-parser");
const documentation_service_1 = require("./services/documentation-service");
const comments_extractor_1 = require("./services/comments-extractor");
function init() {
    const container = new inversify_1.Container();
    container.bind(types_1.TYPES.FileOutputStream).to(file_output_stream_1.FileOutputStreamImpl).inSingletonScope();
    container.bind(types_1.TYPES.TemplateEngine).to(template_engine_1.TemplateEngineImpl).inSingletonScope();
    container.bind(types_1.TYPES.CommentsExtractor).to(comments_extractor_1.CommentsExtractorImpl).inSingletonScope();
    container.bind(types_1.TYPES.TagCommentsParser).to(tag_comments_parser_1.TagCommentsParserImpl).inSingletonScope();
    container.bind(types_1.TYPES.MsdnCommentsParser).to(msdn_comments_parser_1.MsdnCommentsParserImpl).inSingletonScope();
    container.bind(types_1.TYPES.DocumentationService).to(documentation_service_1.DocumentationServiceImpl).inSingletonScope();
    container.bind(types_1.TYPES.Cli).to(cli_1.Cli).inSingletonScope();
    return container.get(types_1.TYPES.Cli);
}
exports.init = init;
const app = init();
app.main(process.argv);
