"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentsExtractorImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const fs = tslib_1.__importStar(require("fs"));
const path = tslib_1.__importStar(require("path"));
const comment_style_1 = require("../model/comment-style");
let CommentsExtractorImpl = class CommentsExtractorImpl {
    extract(commentStyle, filePath) {
        const commentsRegex = comment_style_1.CommentsRegex.from(commentStyle);
        const data = fs.readFileSync(filePath, 'utf8');
        const lines = data.split(/\r?\n/);
        let comments = [];
        const fileComments = [];
        let isFileComments = false;
        let isComments = false;
        const functions = [];
        const modules = [];
        let lineCounter = 1;
        lines.forEach((line) => {
            if (commentsRegex.contentRegex.test(line) && (isFileComments || isComments)) {
                if (isFileComments) {
                    fileComments.push(line);
                }
                if (isComments) {
                    comments.push(line);
                }
            }
            else if (commentsRegex.fileCommentsRegex.test(line)) {
                isFileComments = !isFileComments;
                isComments = false;
            }
            else if (commentsRegex.documentationRegex.test(line)) {
                isComments = !isComments;
                isFileComments = false;
            }
            else if (/^\s*function-id\..+/i.test(line)) {
                functions.push({
                    name: line.split(".")[1].trim(),
                    line: lineCounter,
                    comments: this._cleanComments(comments, commentsRegex),
                });
                comments = [];
            }
            else if (/^\s*program-id\..+/i.test(line)) {
                modules.push({
                    name: line.split(".")[1].trim(),
                    line: lineCounter,
                    comments: this._cleanComments(comments, commentsRegex),
                });
                comments = [];
            }
            lineCounter++;
        });
        return {
            fileName: path.basename(filePath),
            fileComments: this._cleanComments(fileComments, commentsRegex),
            functions: functions,
            modules: modules,
        };
    }
    _cleanComments(comments, commentsRegex) {
        return comments
            .map(comment => comment.replace(commentsRegex.cleanRegex, ''))
            .join('\n');
    }
};
CommentsExtractorImpl = tslib_1.__decorate([
    inversify_1.injectable()
], CommentsExtractorImpl);
exports.CommentsExtractorImpl = CommentsExtractorImpl;
