"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentationServiceImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const path = tslib_1.__importStar(require("path"));
const types_1 = require("../types");
const format_1 = require("../model/format");
const kleur_1 = tslib_1.__importDefault(require("kleur"));
const annotation_type_1 = require("../model/annotation-type");
let DocumentationServiceImpl = class DocumentationServiceImpl {
    constructor(_commentsExtractor, _tagCommentsParser, _msdnCommentsParser, _templateEngine, _outputStream) {
        this._commentsExtractor = _commentsExtractor;
        this._tagCommentsParser = _tagCommentsParser;
        this._msdnCommentsParser = _msdnCommentsParser;
        this._templateEngine = _templateEngine;
        this._outputStream = _outputStream;
    }
    parse(files, outputDirectory, format, commentStyle, annotationType) {
        console.log(`Output directory: ${outputDirectory}`);
        console.log(`Selected format: ${format}`);
        console.log(`Selected comment style: ${commentStyle}`);
        console.log(`Selected annotation type: ${annotationType}`);
        const commentsParser = this._getCommentsParser(annotationType);
        const exportedFiles = [];
        files.forEach(file => {
            this._parseFile(file, outputDirectory, format, commentStyle, commentsParser, exportedFiles);
        });
        const tableOfContents = format_1.TableOfContents.from(format);
        if (!!tableOfContents) {
            process.stdout.write(`Generating ${tableOfContents}... `);
            const outputContent = this._templateEngine.parseTableOfContents(format, exportedFiles);
            this._outputStream.write(outputDirectory, tableOfContents, outputContent);
            console.log(kleur_1.default.green('DONE'));
        }
    }
    _parseFile(file, outputDirectory, format, commentStyle, commentsParser, exportedFiles) {
        const filePath = this._defineFilePath(file);
        const baseName = path.basename(filePath);
        const exportedFileName = `${baseName}.${format_1.OutputFormat.from(format)}`;
        process.stdout.write(`Generating ${baseName} documentation... `);
        const preDocumentation = this._commentsExtractor.extract(commentStyle, filePath);
        const documentation = commentsParser.parse(preDocumentation);
        const outputContent = this._templateEngine.parseDocumentation(format, documentation);
        this._outputStream.write(outputDirectory, exportedFileName, outputContent);
        console.log(kleur_1.default.green('DONE'));
        exportedFiles.push(exportedFileName);
    }
    _defineFilePath(file) {
        let filePath = file;
        if (!path.isAbsolute(file)) {
            filePath = path.join(process.cwd(), file);
        }
        return filePath;
    }
    _getCommentsParser(annotationType) {
        switch (annotationType) {
            case annotation_type_1.AnnotationType.TAG:
                return this._tagCommentsParser;
            case annotation_type_1.AnnotationType.MSDN:
                return this._msdnCommentsParser;
            default:
                throw new Error(`Annotation type not supported: ${annotationType}`);
        }
    }
};
DocumentationServiceImpl = tslib_1.__decorate([
    inversify_1.injectable(),
    tslib_1.__param(0, inversify_1.inject(types_1.TYPES.CommentsExtractor)),
    tslib_1.__param(1, inversify_1.inject(types_1.TYPES.TagCommentsParser)),
    tslib_1.__param(2, inversify_1.inject(types_1.TYPES.MsdnCommentsParser)),
    tslib_1.__param(3, inversify_1.inject(types_1.TYPES.TemplateEngine)),
    tslib_1.__param(4, inversify_1.inject(types_1.TYPES.FileOutputStream)),
    tslib_1.__metadata("design:paramtypes", [Object, Object, Object, Object, Object])
], DocumentationServiceImpl);
exports.DocumentationServiceImpl = DocumentationServiceImpl;
