"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MsdnCommentsParserImpl = void 0;
const tslib_1 = require("tslib");
const inversify_1 = require("inversify");
const xml2js = tslib_1.__importStar(require("xml2js"));
let MsdnCommentsParserImpl = class MsdnCommentsParserImpl {
    constructor() { }
    parse(preDocumentation) {
        const [fileDescription, author, license] = this._extractFileDetails(preDocumentation.fileComments);
        const modules = preDocumentation.modules.map(preModule => this._extractModuleOrFunction(preModule));
        const functions = preDocumentation.functions.map(preFunction => this._extractModuleOrFunction(preFunction));
        return {
            fileName: preDocumentation.fileName,
            fileDescription: fileDescription,
            author: author,
            license: license,
            functions: functions,
            modules: modules,
        };
    }
    _extractModuleOrFunction(preModuleOrFunction) {
        let parsed = {};
        xml2js.parseString(`<root>${preModuleOrFunction.comments}</root>`, {
            async: false,
            ignoreAttrs: false,
        }, (err, result) => {
            if (!!err) {
                throw err;
            }
            parsed = result.root;
        });
        const params = [];
        if (!!parsed.param) {
            for (const param of parsed.param) {
                params.push({
                    name: !!param['$'] ? param['$']['name'] : undefined,
                    description: param['_'],
                    type: !!param['$'] ? param['$']['type'] : undefined,
                });
            }
        }
        let returnObj = undefined;
        if (!!parsed.returns && parsed.returns.length > 0) {
            returnObj = {
                description: parsed.returns[0]['_'],
                type: !!parsed.returns[0]['$'] ? parsed.returns[0]['$']['type'] : undefined,
            };
        }
        const summary = this._extractTag(preModuleOrFunction.comments, 'summary');
        const remarks = this._extractTag(preModuleOrFunction.comments, 'remarks');
        const example = this._extractTag(preModuleOrFunction.comments, 'example');
        return {
            description: summary,
            summary: remarks || summary,
            example: example,
            line: preModuleOrFunction.line,
            name: preModuleOrFunction.name,
            paragraphs: [],
            params: params,
            return: returnObj,
        };
    }
    _extractTag(comment, tag) {
        if (comment.includes(`<${tag}>`) && comment.includes(`</${tag}>`)) {
            return comment.split(`<${tag}>`)[1].split(`</${tag}>`)[0];
        }
        return undefined;
    }
    _extractFileDetails(comments) {
        let parsed = {};
        xml2js.parseString(`<root>${comments}</root>`, {
            async: false,
            ignoreAttrs: false,
        }, (err, result) => {
            if (!!err) {
                throw err;
            }
            parsed = result.root;
        });
        const summary = !!parsed.summary && parsed.summary.length > 0 ? parsed.summary[0] : undefined;
        const author = !!parsed.author && parsed.author.length > 0 ? parsed.author[0] : undefined;
        const license = !!parsed.license && parsed.license.length > 0 ? parsed.license[0] : undefined;
        return [summary, author, license];
    }
};
MsdnCommentsParserImpl = tslib_1.__decorate([
    inversify_1.injectable(),
    tslib_1.__metadata("design:paramtypes", [])
], MsdnCommentsParserImpl);
exports.MsdnCommentsParserImpl = MsdnCommentsParserImpl;
